@@ -607,10 +607,15 @@ class CreateAthena(luigi.Task):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        if not self.s3_export_path.replace("-", "").endswith(f"/{self.athena_db_name}"):
+        if not self.s3_export_path.replace("-", "").endswith(
+            "/" + self.athena_db_name.split("_", 1)[1]
+        ):
             raise ValueError(
                 f"S3 export path ({self.s3_export_path}) does not match "
-                f"Athena database name ({self.athena_db_name})"
+                f"Athena database name ({self.athena_db_name})."
+                f"They should use these formats: "
+                f"'s3://<whatever>/YYYY-MM-DD[_<flavor>]/' "
+                f"and '<prefix>_YYYYMMDD[_<flavor>]"
             )
 
     def requires(self) -> List[luigi.Task]:
@@ -656,7 +661,9 @@ class RunExportAll(luigi.Task):
                 --s3-athena-output-location=s3://softwareheritage/graph/tmp/athena
     """
 
-    formats = luigi.EnumListParameter(enum=Format, batch_method=merge_lists)
+    formats = luigi.EnumListParameter(
+        enum=Format, batch_method=merge_lists, default=list(Format)
+    )
     object_types = luigi.EnumListParameter(
         enum=ObjectType, default=list(ObjectType), batch_method=merge_lists
     )
